

KDEs provide a means of non-parametric density estimation.

An extensive introduction and explanation can be found in
:ref:`sec-kernel-density-estimation`.

.. autosummary::
    :toctree: _generated/kde_api

    zfit.pdf.KDE1DimExact
    zfit.pdf.KDE1DimGrid
    zfit.pdf.KDE1DimFFT
    zfit.pdf.KDE1DimISJ
    zfit.pdf.GaussianKDE1DimV1
